# Generated by Django 3.2.16 on 2023-04-04 05:35

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="OIDCSession",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("state", models.TextField()),
                ("session_state", models.TextField(null=True)),
                ("sub", models.TextField()),
                ("cache_session_key", models.TextField()),
                ("created_at", models.DateTimeField(auto_now_add=True)),
            ],
        )
    ]
