from django_pyoidc.providers.lemonldapng2 import LemonLDAPng2Provider


class LemonLDAPngProvider(LemonLDAPng2Provider):
    """
    Provide django settings/urlconf based on LemonLDAP-ng behaviour (latest version).

    For older LemonLDAPNg versions please check the other Klemonldapng_* providers.
    """

    pass
